@@ -33,6 +33,8 @@
  *
  */
 
+#include "config.h"
+
 #include <libotr/proto.h>
 #include <libotr/privkey.h>
 #include <libotr/message.h>
@@ -40,6 +42,8 @@
 #include <glib.h>
 
 #include "log.h"
+#include "chatlog.h"
+#include "database.h"
 #include "config/preferences.h"
 #include "config/files.h"
 #include "otr/otr.h"
@@ -51,15 +55,15 @@
 #include "xmpp/contact.h"
 #include "xmpp/xmpp.h"
 
-#define PRESENCE_ONLINE 1
+#define PRESENCE_ONLINE  1
 #define PRESENCE_OFFLINE 0
 #define PRESENCE_UNKNOWN -1
 
 static OtrlUserState user_state;
 static OtrlMessageAppOps ops;
-static char *jid;
+static char* jid;
 static gboolean data_loaded;
-static GHashTable *smp_initiators;
+static GHashTable* smp_initiators;
 
 OtrlUserState
 otr_userstate(void)
@@ -81,13 +85,13 @@ otr_smpinitators(void)
 
 // ops callbacks
 static OtrlPolicy
-cb_policy(void *opdata, ConnContext *context)
+cb_policy(void* opdata, ConnContext* context)
 {
     return otrlib_policy();
 }
 
 static int
-cb_is_logged_in(void *opdata, const char *accountname, const char *protocol, const char *recipient)
+cb_is_logged_in(void* opdata, const char* accountname, const char* protocol, const char* recipient)
 {
     jabber_conn_status_t conn_status = connection_get_status();
     if (conn_status != JABBER_CONNECTED) {
@@ -115,44 +119,36 @@ cb_is_logged_in(void *opdata, const char *accountname, const char *protocol, con
 }
 
 static void
-cb_inject_message(void *opdata, const char *accountname,
-    const char *protocol, const char *recipient, const char *message)
+cb_inject_message(void* opdata, const char* accountname,
+                  const char* protocol, const char* recipient, const char* message)
 {
-    char *id = message_send_chat_otr(recipient, message, FALSE);
-    free(id);
+    free(message_send_chat_otr(recipient, message, FALSE, NULL));
 }
 
 static void
-cb_write_fingerprints(void *opdata)
+cb_write_fingerprints(void* opdata)
 {
     gcry_error_t err = 0;
+    auto_gchar gchar* fpsfilename = files_file_in_account_data_path(DIR_OTR, jid, "fingerprints.txt");
+    if (!fpsfilename) {
+        log_error("Failed to create fingerprints file");
+        cons_show_error("Failed to create fingerprints file");
+        return;
+    }
 
-    char *otrdir = files_get_data_path(DIR_OTR);
-    GString *basedir = g_string_new(otrdir);
-    free(otrdir);
-    gchar *account_dir = str_replace(jid, "@", "_at_");
-    g_string_append(basedir, "/");
-    g_string_append(basedir, account_dir);
-    g_string_append(basedir, "/");
-    free(account_dir);
-
-    GString *fpsfilename = g_string_new(basedir->str);
-    g_string_append(fpsfilename, "fingerprints.txt");
-    err = otrl_privkey_write_fingerprints(user_state, fpsfilename->str);
+    err = otrl_privkey_write_fingerprints(user_state, fpsfilename);
     if (err != GPG_ERR_NO_ERROR) {
         log_error("Failed to write fingerprints file");
-        cons_show_error("Failed to create fingerprints file");
+        cons_show_error("Failed to write fingerprints file");
     }
-    g_string_free(basedir, TRUE);
-    g_string_free(fpsfilename, TRUE);
 }
 
 static void
-cb_gone_secure(void *opdata, ConnContext *context)
+cb_gone_secure(void* opdata, ConnContext* context)
 {
-    ProfChatWin *chatwin = wins_get_chat(context->username);
+    ProfChatWin* chatwin = wins_get_chat(context->username);
     if (!chatwin) {
-        chatwin = (ProfChatWin*) wins_new_chat(context->username);
+        chatwin = chatwin_new(context->username);
     }
 
     chatwin_otr_secured(chatwin, otr_is_trusted(context->username));
@@ -207,7 +203,7 @@ otr_poll(void)
 }
 
 void
-otr_on_connect(ProfAccount *account)
+otr_on_connect(ProfAccount* account)
 {
     if (jid) {
         free(jid);
@@ -215,19 +211,10 @@ otr_on_connect(ProfAccount *account)
     jid = strdup(account->jid);
     log_info("Loading OTR key for %s", jid);
 
-    char *otrdir = files_get_data_path(DIR_OTR);
-    GString *basedir = g_string_new(otrdir);
-    free(otrdir);
-    gchar *account_dir = str_replace(jid, "@", "_at_");
-    g_string_append(basedir, "/");
-    g_string_append(basedir, account_dir);
-    g_string_append(basedir, "/");
-    free(account_dir);
-
-    if (!mkdir_recursive(basedir->str)) {
-        log_error("Could not create %s for account %s.", basedir->str, jid);
-        cons_show_error("Could not create %s for account %s.", basedir->str, jid);
-        g_string_free(basedir, TRUE);
+    auto_gchar gchar* otr_dir = files_file_in_account_data_path(DIR_OTR, jid, NULL);
+    if (!otr_dir) {
+        log_error("Could not create directory for account %s.", jid);
+        cons_show_error("Could not create directory for account %s.", jid);
         return;
     }
 
@@ -238,8 +225,8 @@ otr_on_connect(ProfAccount *account)
 
     gcry_error_t err = 0;
 
-    GString *keysfilename = g_string_new(basedir->str);
-    g_string_append(keysfilename, "keys.txt");
+    GString* keysfilename = g_string_new(otr_dir);
+    g_string_append(keysfilename, "/keys.txt");
     if (!g_file_test(keysfilename->str, G_FILE_TEST_IS_REGULAR)) {
         log_info("No OTR private key file found %s", keysfilename->str);
         data_loaded = FALSE;
@@ -249,7 +236,6 @@ otr_on_connect(ProfAccount *account)
         if (err != GPG_ERR_NO_ERROR) {
             log_warning("Failed to read OTR private key file: %s", keysfilename->str);
             cons_show_error("Failed to read OTR private key file: %s", keysfilename->str);
-            g_string_free(basedir, TRUE);
             g_string_free(keysfilename, TRUE);
             return;
         }
@@ -258,7 +244,6 @@ otr_on_connect(ProfAccount *account)
         if (!privkey) {
             log_warning("No OTR private key found for account \"%s\", protocol \"xmpp\" in file: %s", jid, keysfilename->str);
             cons_show_error("No OTR private key found for account \"%s\", protocol \"xmpp\" in file: %s", jid, keysfilename->str);
-            g_string_free(basedir, TRUE);
             g_string_free(keysfilename, TRUE);
             return;
         }
@@ -266,8 +251,8 @@ otr_on_connect(ProfAccount *account)
         data_loaded = TRUE;
     }
 
-    GString *fpsfilename = g_string_new(basedir->str);
-    g_string_append(fpsfilename, "fingerprints.txt");
+    GString* fpsfilename = g_string_new(otr_dir);
+    g_string_append(fpsfilename, "/fingerprints.txt");
     if (!g_file_test(fpsfilename->str, G_FILE_TEST_IS_REGULAR)) {
         log_info("No OTR fingerprints file found %s", fpsfilename->str);
         data_loaded = FALSE;
@@ -276,7 +261,6 @@ otr_on_connect(ProfAccount *account)
         err = otrl_privkey_read_fingerprints(user_state, fpsfilename->str, NULL, NULL);
         if (err != GPG_ERR_NO_ERROR) {
             log_error("Failed to load OTR fingerprints file: %s", fpsfilename->str);
-            g_string_free(basedir, TRUE);
             g_string_free(keysfilename, TRUE);
             g_string_free(fpsfilename, TRUE);
             return;
@@ -290,19 +274,18 @@ otr_on_connect(ProfAccount *account)
         cons_show("Loaded OTR private key for %s", jid);
     }
 
-    g_string_free(basedir, TRUE);
     g_string_free(keysfilename, TRUE);
     g_string_free(fpsfilename, TRUE);
     return;
 }
 
 char*
-otr_on_message_recv(const char *const barejid, const char *const resource, const char *const message, gboolean *decrypted)
+otr_on_message_recv(const char* const barejid, const char* const resource, const char* const message, gboolean* decrypted)
 {
     prof_otrpolicy_t policy = otr_get_policy(barejid);
-    char *whitespace_base = strstr(message, OTRL_MESSAGE_TAG_BASE);
+    char* whitespace_base = strstr(message, OTRL_MESSAGE_TAG_BASE);
 
-    //check for OTR whitespace (opportunistic or always)
+    // check for OTR whitespace (opportunistic or always)
     if (policy == PROF_OTRPOLICY_OPPORTUNISTIC || policy == PROF_OTRPOLICY_ALWAYS) {
         if (whitespace_base) {
             if (strstr(message, OTRL_MESSAGE_TAG_V2) || strstr(message, OTRL_MESSAGE_TAG_V1)) {
@@ -312,66 +295,62 @@ otr_on_message_recv(const char *const barejid, const char *const resource, const
                 if (strstr(message, OTRL_MESSAGE_TAG_V2) && strstr(message, OTRL_MESSAGE_TAG_V1)) {
                     tag_length = 32;
                 }
-                memmove(whitespace_base, whitespace_base+tag_length, tag_length);
-                char *otr_query_message = otr_start_query();
-                cons_show("OTR Whitespace pattern detected. Attempting to start OTR session...");
-                char *id = message_send_chat_otr(barejid, otr_query_message, FALSE);
-                free(id);
+                memmove(whitespace_base, whitespace_base + tag_length, tag_length);
+                char* otr_query_message = otr_start_query();
+                cons_show("OTR Whitespace pattern detected. Attempting to start OTR session…");
+                free(message_send_chat_otr(barejid, otr_query_message, FALSE, NULL));
             }
         }
     }
 
-    char *newmessage = otr_decrypt_message(barejid, message, decrypted);
+    char* newmessage = otr_decrypt_message(barejid, message, decrypted);
     if (!newmessage) { // internal OTR message
         return NULL;
     }
 
     if (policy == PROF_OTRPOLICY_ALWAYS && *decrypted == FALSE && !whitespace_base) {
-        char *otr_query_message = otr_start_query();
-        cons_show("Attempting to start OTR session...");
-        char *id = message_send_chat_otr(barejid, otr_query_message, FALSE);
-        free(id);
+        char* otr_query_message = otr_start_query();
+        cons_show("Attempting to start OTR session…");
+        free(message_send_chat_otr(barejid, otr_query_message, FALSE, NULL));
     }
 
     return newmessage;
 }
 
 gboolean
-otr_on_message_send(ProfChatWin *chatwin, const char *const message, gboolean request_receipt)
+otr_on_message_send(ProfChatWin* chatwin, const char* const message, gboolean request_receipt, const char* const replace_id)
 {
-    char *id = NULL;
+    auto_char char* id = NULL;
     prof_otrpolicy_t policy = otr_get_policy(chatwin->barejid);
 
     // Send encrypted message
     if (otr_is_secure(chatwin->barejid)) {
-        char *encrypted = otr_encrypt_message(chatwin->barejid, message);
+        char* encrypted = otr_encrypt_message(chatwin->barejid, message);
         if (encrypted) {
-            id = message_send_chat_otr(chatwin->barejid, encrypted, request_receipt);
+            id = message_send_chat_otr(chatwin->barejid, encrypted, request_receipt, replace_id);
             chat_log_otr_msg_out(chatwin->barejid, message, NULL);
-            chatwin_outgoing_msg(chatwin, message, id, PROF_MSG_ENC_OTR, request_receipt);
+            log_database_add_outgoing_chat(id, chatwin->barejid, message, replace_id, PROF_MSG_ENC_OTR);
+            chatwin_outgoing_msg(chatwin, message, id, PROF_MSG_ENC_OTR, request_receipt, replace_id);
             otr_free_message(encrypted);
-            free(id);
             return TRUE;
         } else {
-            win_println((ProfWin*)chatwin, THEME_ERROR, '-', "%s", "Failed to encrypt and send message.");
+            win_println((ProfWin*)chatwin, THEME_ERROR, "-", "%s", "Failed to encrypt and send message.");
             return TRUE;
         }
     }
 
     // show error if not secure and policy always
     if (policy == PROF_OTRPOLICY_ALWAYS) {
-        win_println((ProfWin*)chatwin, THEME_ERROR, '-', "%s", "Failed to send message. OTR policy set to: always");
+        win_println((ProfWin*)chatwin, THEME_ERROR, "-", "%s", "Failed to send message. OTR policy set to: always");
         return TRUE;
     }
 
     // tag and send for policy opportunistic
     if (policy == PROF_OTRPOLICY_OPPORTUNISTIC) {
-        char *otr_tagged_msg = otr_tag_message(message);
-        id = message_send_chat_otr(chatwin->barejid, otr_tagged_msg, request_receipt);
-        chatwin_outgoing_msg(chatwin, message, id, PROF_MSG_ENC_PLAIN, request_receipt);
+        auto_char char* otr_tagged_msg = otr_tag_message(message);
+        id = message_send_chat_otr(chatwin->barejid, otr_tagged_msg, request_receipt, replace_id);
+        chatwin_outgoing_msg(chatwin, message, id, PROF_MSG_ENC_NONE, request_receipt, replace_id);
         chat_log_msg_out(chatwin->barejid, message, NULL);
-        free(otr_tagged_msg);
-        free(id);
         return TRUE;
     }
 
@@ -379,46 +358,35 @@ otr_on_message_send(ProfChatWin *chatwin, const char *const message, gboolean re
 }
 
 void
-otr_keygen(ProfAccount *account)
+otr_keygen(ProfAccount* account)
 {
     if (data_loaded) {
         cons_show("OTR key already generated.");
         return;
     }
 
-    if (jid) {
-        free(jid);
-    }
+    free(jid);
     jid = strdup(account->jid);
     log_info("Generating OTR key for %s", jid);
 
-    char *otrdir = files_get_data_path(DIR_OTR);
-    GString *basedir = g_string_new(otrdir);
-    free(otrdir);
-    gchar *account_dir = str_replace(jid, "@", "_at_");
-    g_string_append(basedir, "/");
-    g_string_append(basedir, account_dir);
-    g_string_append(basedir, "/");
-    free(account_dir);
+    auto_gchar gchar* otr_dir = files_file_in_account_data_path(DIR_OTR, jid, NULL);
 
-    if (!mkdir_recursive(basedir->str)) {
-        log_error("Could not create %s for account %s.", basedir->str, jid);
-        cons_show_error("Could not create %s for account %s.", basedir->str, jid);
-        g_string_free(basedir, TRUE);
+    if (!otr_dir) {
+        log_error("Could not create directory for account %s.", jid);
+        cons_show_error("Could not create directory for account %s.", jid);
         return;
     }
 
     gcry_error_t err = 0;
 
-    GString *keysfilename = g_string_new(basedir->str);
-    g_string_append(keysfilename, "keys.txt");
+    GString* keysfilename = g_string_new(otr_dir);
+    g_string_append(keysfilename, "/keys.txt");
     log_debug("Generating private key file %s for %s", keysfilename->str, jid);
     cons_show("Generating private key, this may take some time.");
     cons_show("Moving the mouse randomly around the screen may speed up the process!");
     ui_update();
     err = otrl_privkey_generate(user_state, keysfilename->str, account->jid, "xmpp");
     if (err != GPG_ERR_NO_ERROR) {
-        g_string_free(basedir, TRUE);
         g_string_free(keysfilename, TRUE);
         log_error("Failed to generate private key");
         cons_show_error("Failed to generate private key");
@@ -428,12 +396,11 @@ otr_keygen(ProfAccount *account)
     cons_show("");
     cons_show("Private key generation complete.");
 
-    GString *fpsfilename = g_string_new(basedir->str);
-    g_string_append(fpsfilename, "fingerprints.txt");
+    GString* fpsfilename = g_string_new(otr_dir);
+    g_string_append(fpsfilename, "/fingerprints.txt");
     log_debug("Generating fingerprints file %s for %s", fpsfilename->str, jid);
     err = otrl_privkey_write_fingerprints(user_state, fpsfilename->str);
     if (err != GPG_ERR_NO_ERROR) {
-        g_string_free(basedir, TRUE);
         g_string_free(keysfilename, TRUE);
         log_error("Failed to create fingerprints file");
         cons_show_error("Failed to create fingerprints file");
@@ -443,7 +410,6 @@ otr_keygen(ProfAccount *account)
 
     err = otrl_privkey_read(user_state, keysfilename->str);
     if (err != GPG_ERR_NO_ERROR) {
-        g_string_free(basedir, TRUE);
         g_string_free(keysfilename, TRUE);
         log_error("Failed to load private key");
         data_loaded = FALSE;
@@ -452,7 +418,6 @@ otr_keygen(ProfAccount *account)
 
     err = otrl_privkey_read_fingerprints(user_state, fpsfilename->str, NULL, NULL);
     if (err != GPG_ERR_NO_ERROR) {
-        g_string_free(basedir, TRUE);
         g_string_free(keysfilename, TRUE);
         log_error("Failed to load fingerprints");
         data_loaded = FALSE;
@@ -461,7 +426,6 @@ otr_keygen(ProfAccount *account)
 
     data_loaded = TRUE;
 
-    g_string_free(basedir, TRUE);
     g_string_free(keysfilename, TRUE);
     g_string_free(fpsfilename, TRUE);
     return;
@@ -474,21 +438,15 @@ otr_key_loaded(void)
 }
 
 char*
-otr_tag_message(const char *const msg)
+otr_tag_message(const char* const msg)
 {
-    GString *otr_message = g_string_new(msg);
-    g_string_append(otr_message, OTRL_MESSAGE_TAG_BASE);
-    g_string_append(otr_message, OTRL_MESSAGE_TAG_V2);
-    char *result = otr_message->str;
-    g_string_free(otr_message, FALSE);
-
-    return result;
+    return g_strdup_printf("%s%s%s", msg, OTRL_MESSAGE_TAG_BASE, OTRL_MESSAGE_TAG_V2);
 }
 
 gboolean
-otr_is_secure(const char *const recipient)
+otr_is_secure(const char* const recipient)
 {
-    ConnContext *context = otrlib_context_find(user_state, recipient, jid);
+    ConnContext* context = otrlib_context_find(user_state, recipient, jid);
 
     if (context == NULL) {
         return FALSE;
@@ -502,9 +460,9 @@ otr_is_secure(const char *const recipient)
 }
 
 gboolean
-otr_is_trusted(const char *const recipient)
+otr_is_trusted(const char* const recipient)
 {
-    ConnContext *context = otrlib_context_find(user_state, recipient, jid);
+    ConnContext* context = otrlib_context_find(user_state, recipient, jid);
 
     if (context == NULL) {
         return FALSE;
@@ -528,9 +486,9 @@ otr_is_trusted(const char *const recipient)
 }
 
 void
-otr_trust(const char *const recipient)
+otr_trust(const char* const recipient)
 {
-    ConnContext *context = otrlib_context_find(user_state, recipient, jid);
+    ConnContext* context = otrlib_context_find(user_state, recipient, jid);
 
     if (context == NULL) {
         return;
@@ -552,9 +510,9 @@ otr_trust(const char *const recipient)
 }
 
 void
-otr_untrust(const char *const recipient)
+otr_untrust(const char* const recipient)
 {
-    ConnContext *context = otrlib_context_find(user_state, recipient, jid);
+    ConnContext* context = otrlib_context_find(user_state, recipient, jid);
 
     if (context == NULL) {
         return;
@@ -576,9 +534,9 @@ otr_untrust(const char *const recipient)
 }
 
 void
-otr_smp_secret(const char *const recipient, const char *secret)
+otr_smp_secret(const char* const recipient, const char* secret)
 {
-    ConnContext *context = otrlib_context_find(user_state, recipient, jid);
+    ConnContext* context = otrlib_context_find(user_state, recipient, jid);
 
     if (context == NULL) {
         return;
@@ -589,7 +547,7 @@ otr_smp_secret(const char *const recipient, const char *secret)
     }
 
     // if recipient initiated SMP, send response, else initialise
-    ProfChatWin *chatwin = wins_get_chat(recipient);
+    ProfChatWin* chatwin = wins_get_chat(recipient);
     if (g_hash_table_contains(smp_initiators, recipient)) {
         otrl_message_respond_smp(user_state, &ops, NULL, context, (const unsigned char*)secret, strlen(secret));
         if (chatwin) {
@@ -605,9 +563,9 @@ otr_smp_secret(const char *const recipient, const char *secret)
 }
 
 void
-otr_smp_question(const char *const recipient, const char *question, const char *answer)
+otr_smp_question(const char* const recipient, const char* question, const char* answer)
 {
-    ConnContext *context = otrlib_context_find(user_state, recipient, jid);
+    ConnContext* context = otrlib_context_find(user_state, recipient, jid);
 
     if (context == NULL) {
         return;
@@ -618,16 +576,16 @@ otr_smp_question(const char *const recipient, const char *question, const char *
     }
 
     otrl_message_initiate_smp_q(user_state, &ops, NULL, context, question, (const unsigned char*)answer, strlen(answer));
-    ProfChatWin *chatwin = wins_get_chat(recipient);
+    ProfChatWin* chatwin = wins_get_chat(recipient);
     if (chatwin) {
         chatwin_otr_smp_event(chatwin, PROF_OTR_SMP_AUTH_WAIT, NULL);
     }
 }
 
 void
-otr_smp_answer(const char *const recipient, const char *answer)
+otr_smp_answer(const char* const recipient, const char* answer)
 {
-    ConnContext *context = otrlib_context_find(user_state, recipient, jid);
+    ConnContext* context = otrlib_context_find(user_state, recipient, jid);
 
     if (context == NULL) {
         return;
@@ -642,7 +600,7 @@ otr_smp_answer(const char *const recipient, const char *answer)
 }
 
 void
-otr_end_session(const char *const recipient)
+otr_end_session(const char* const recipient)
 {
     otrlib_end_session(user_state, recipient, jid, &ops);
 }
@@ -652,18 +610,18 @@ otr_get_my_fingerprint(void)
 {
     char fingerprint[45];
     otrl_privkey_fingerprint(user_state, fingerprint, jid, "xmpp");
-    char *result = strdup(fingerprint);
+    char* result = strdup(fingerprint);
 
     return result;
 }
 
 char*
-otr_get_their_fingerprint(const char *const recipient)
+otr_get_their_fingerprint(const char* const recipient)
 {
-    ConnContext *context = otrlib_context_find(user_state, recipient, jid);
+    ConnContext* context = otrlib_context_find(user_state, recipient, jid);
 
     if (context) {
-        Fingerprint *fingerprint = context->active_fingerprint;
+        Fingerprint* fingerprint = context->active_fingerprint;
         char readable[45];
         otrl_privkey_hash_to_human(readable, fingerprint->fingerprint);
         return strdup(readable);
@@ -673,10 +631,10 @@ otr_get_their_fingerprint(const char *const recipient)
 }
 
 prof_otrpolicy_t
-otr_get_policy(const char *const recipient)
+otr_get_policy(const char* const recipient)
 {
-    char *account_name = session_get_account_name();
-    ProfAccount *account = accounts_get_account(account_name);
+    char* account_name = session_get_account_name();
+    ProfAccount* account = accounts_get_account(account_name);
     // check contact specific setting
     if (g_list_find_custom(account->otr_manual, recipient, (GCompareFunc)g_strcmp0)) {
         account_free(account);
@@ -709,7 +667,7 @@ otr_get_policy(const char *const recipient)
     account_free(account);
 
     // check global setting
-    char *pref_otr_policy = prefs_get_string(PREF_OTR_POLICY);
+    auto_gchar gchar* pref_otr_policy = prefs_get_string(PREF_OTR_POLICY);
 
     // pref defaults to manual
     prof_otrpolicy_t result = PROF_OTRPOLICY_MANUAL;
@@ -720,15 +678,13 @@ otr_get_policy(const char *const recipient)
         result = PROF_OTRPOLICY_ALWAYS;
     }
 
-    prefs_free_string(pref_otr_policy);
-
     return result;
 }
 
 char*
-otr_encrypt_message(const char *const to, const char *const message)
+otr_encrypt_message(const char* const to, const char* const message)
 {
-    char *newmessage = NULL;
+    char* newmessage = NULL;
     gcry_error_t err = otrlib_encrypt_message(user_state, &ops, jid, to, message, &newmessage);
 
     if (err != 0) {
@@ -739,7 +695,7 @@ otr_encrypt_message(const char *const to, const char *const message)
 }
 
 static void
-_otr_tlv_free(OtrlTLV *tlvs)
+_otr_tlv_free(OtrlTLV* tlvs)
 {
     if (tlvs) {
         otrl_tlv_free(tlvs);
@@ -747,23 +703,23 @@ _otr_tlv_free(OtrlTLV *tlvs)
 }
 
 char*
-otr_decrypt_message(const char *const from, const char *const message, gboolean *decrypted)
+otr_decrypt_message(const char* const from, const char* const message, gboolean* decrypted)
 {
-    char *newmessage = NULL;
-    OtrlTLV *tlvs = NULL;
+    char* newmessage = NULL;
+    OtrlTLV* tlvs = NULL;
 
     int result = otrlib_decrypt_message(user_state, &ops, jid, from, message, &newmessage, &tlvs);
 
     // internal libotr message
     if (result == 1) {
-        ConnContext *context = otrlib_context_find(user_state, from, jid);
+        ConnContext* context = otrlib_context_find(user_state, from, jid);
 
         // common tlv handling
-        OtrlTLV *tlv = otrl_tlv_find(tlvs, OTRL_TLV_DISCONNECTED);
+        OtrlTLV* tlv = otrl_tlv_find(tlvs, OTRL_TLV_DISCONNECTED);
         if (tlv) {
             if (context) {
                 otrl_context_force_plaintext(context);
-                ProfChatWin *chatwin = wins_get_chat(from);
+                ProfChatWin* chatwin = wins_get_chat(from);
                 if (chatwin) {
                     chatwin_otr_unsecured(chatwin);
                 }
@@ -776,7 +732,7 @@ otr_decrypt_message(const char *const from, const char *const message, gboolean
 
         return NULL;
 
-    // message was processed, return to user
+        // message was processed, return to user
     } else if (newmessage) {
         _otr_tlv_free(tlvs);
         if (g_str_has_prefix(message, "?OTR:")) {
@@ -784,7 +740,7 @@ otr_decrypt_message(const char *const from, const char *const message, gboolean
         }
         return newmessage;
 
-    // normal non OTR message
+        // normal non OTR message
     } else {
         _otr_tlv_free(tlvs);
         *decrypted = FALSE;
@@ -793,7 +749,7 @@ otr_decrypt_message(const char *const from, const char *const message, gboolean
 }
 
 void
-otr_free_message(char *message)
+otr_free_message(char* message)
 {
     otrl_message_free(message);
 }
